// Copyright  1998 Sun Microsystems, Inc. All Rights Reserved.
//
package examples.activation; 

import java.io.*;
import java.rmi.*;
import java.rmi.activation.*;
import java.util.Vector;

public class MyPersistentClass extends Activatable
    implements examples.activation.YetAnotherRemoteInterface {

    private Vector transactions;
    private File holder;

    // The constructor for activation and export; this constructor is
    // called by the method ActivationInstantiator.newInstance during
    // activation, to construct the object.
    //
    public MyPersistentClass(ActivationID id, MarshalledObject data) 
	throws RemoteException, ClassNotFoundException, java.io.IOException {

	super(id, 0);

        // Extract the File object from the MarshalledObject that was 
        // passed to the constructor 
	//
	holder = (File)data.get();

	if (holder.exists()) {
	    // Use the MarshalledObject to restore my state
	    //
	    this.restoreState();
	} else {
	    transactions = new Vector(1,1);
	    transactions.addElement("Initializing transaction vector");
	}
    }

    // Define the method declared in AnotherRemoteInterface
    //
    public Vector calltheServer(Vector v) throws RemoteException {

	int limit = v.size();
	for (int i = 0; i < limit; i++) {
	    transactions.addElement(v.elementAt(i));
	}

	// Save this object's data out to file
	//
	this.saveState();
	return transactions;
    }

    public Vector getTransactions() {
	return transactions;
    }


    // If the MarshalledObject that was passed to the constructor was
    // a file, then use it to recover the vector of transaction data
    //
    private void restoreState() throws IOException, ClassNotFoundException {
	File f = holder;
	FileInputStream fis = new FileInputStream(f);
        ObjectInputStream ois = new ObjectInputStream(fis);
        transactions = (Vector)ois.readObject();
        ois.close();
    }

    private void saveState() {
	try {
	    File f  = holder;
	    FileOutputStream fos = new FileOutputStream(f);
	    ObjectOutputStream oos = new ObjectOutputStream(fos);
	    oos.writeObject(getTransactions());
	    oos.close();
	} catch (Exception e) {
	    throw new RuntimeException("Error saving vector of data");
	}
    }
}
