// Copyright  1998 Sun Microsystems, Inc. All Rights Reserved.
//
package examples.activation; 

import java.rmi.*;
import java.rmi.activation.*;
import java.security.CodeSource;
import java.util.Properties;

public class Setup2 {

    // This class registers information about the MyRemoteInterfaceImpl
    // class with rmid and the rmiregistry
    //
    public static void main(String[] args) throws Exception {
	
	System.setSecurityManager(new RMISecurityManager());
	
        MyRemoteInterface mri; // Declare an instance of the interface

	// Don't forget the trailing slash at the end of the URL
	// or your classes won't be found
	//	
	java.net.URL location = 
	    new java.net.URL("file:/home/rmi_tutorial/activation/");

	// The second parameter to the CodeSource constructor 
	// is an object that implements java.security.PublicKey
	// 
	CodeSource source = new CodeSource(location, null);

	// Create the rest of the parameters that will be passed to
	// the ActivationDesc constructor
	//
	Properties props = (Properties)System.getProperties().clone();
	ActivationGroupID agi =
	    ActivationGroup.getSystem().registerGroup(
	                                new ActivationGroupDesc(props));
	MarshalledObject data = null;

	// The second argument to the ActivationDesc constructor will be used 
	// to uniquely identify this class; it's location is relative to the  
	// URL referenced by the CodeSource
	//
	ActivationDesc desc = new ActivationDesc 
	    (agi, "examples.activation.MyRemoteInterfaceImpl", source, data);
	
	mri = (MyRemoteInterface)Activatable.register(desc);
	System.out.println("Got the stub for the MyRemoteInterfaceImpl");

	// Bind the stub to a name in the registry running on 1099
	//
	Naming.rebind("MyRemoteInterfaceImpl", mri);
	System.out.println("Exported MyRemoteInterfaceImpl");

	System.exit(0);
    } 
} 

