 /*
 * @(#)ClassIndexFrameWriter.java	1.1 98/02/10
 *
 * Copyright 1993-1997 Sun Microsystems, Inc. 901 San Antonio Road,
 * Palo Alto, California, 94303, U.S.A.  All Rights Reserved.
 *
 * This software is the confidential and proprietary information of Sun
 * Microsystems, Inc. ("Confidential Information").  You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered into
 * with Sun.
 *
 * CopyrightVersion 1.2
 *
 */

package sun.tools.javadoc.doclets;

import sun.tools.javadoc.*;
import java.io.*;

/**
 * Generate class index to live in a frame. 
 *
 * @author Robert Field
 */
public class ClassIndexFrameWriter extends AbstractIndexWriter {

    public ClassIndexFrameWriter(String filename, 
                             IndexBuilder indexbuilder) throws IOException {
        super(filename, indexbuilder);
    }

    /**
     * Generate a single index file, listing all the members.
     *
     */
    public static void generate(IndexBuilder indexbuilder) 
                                throws DocletAbortException {
        ClassIndexFrameWriter indexgen;
        String filename = "classindex-frame.html";
        try {
            indexgen = new ClassIndexFrameWriter(filename, indexbuilder);
            indexgen.generateIndexFile();
            indexgen.close();
        } catch (IOException exc) {
            error("doclet.exception_encountered", exc.toString(), filename);
            throw new DocletAbortException();
        }
    }

    /**
     * Generate the contents of the index file.
     */
    protected void generateIndexFile() throws IOException {
        printHeader(getText("doclet.Class_Index"));

        for (int i = 0; i < indexbuilder.elements.length; i++) {
            Character unicode = (Character)indexbuilder.elements[i];
            generateContents(unicode, indexbuilder.getMemberList(unicode));
        }

        printFooter();
    }

    protected void printDescription(ClassDoc cd) {
        dt();
        printTargetClassLink(cd, "classFrame");
    }

    /**
     * Print Links for all the Index Files per alphabet.
     *
     */
    protected void printLinksForIndexes() {
        for (int i = 0; i < indexbuilder.elements.length; i++) {
            String unicode = indexbuilder.elements[i].toString();
            printHyperLink("#_" + unicode + "_", unicode);
            print(' ');
        }
    }
}
