/*
 * @(#)PackageIndexFrameWriter.java	1.0 98/01/20
 *
 * Copyright 1993-1997 Sun Microsystems, Inc. 901 San Antonio Road,
 * Palo Alto, California, 94303, U.S.A.  All Rights Reserved.
 *
 * This software is the confidential and proprietary information of Sun
 * Microsystems, Inc. ("Confidential Information").  You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered into
 * with Sun.
 *
 * CopyrightVersion 1.2
 *
 */

package sun.tools.javadoc.doclets;

import sun.tools.javadoc.*;
import java.io.*;
import java.lang.*;
import java.util.*;

/**
 * Write out the package index.
 *
 * @see sun.tools.javadoc.PackageDoc
 * @see sun.tools.javadoc.doclets.HtmlDocWriter
 * @author Atul M Dambalkar 
 */
public class PackageIndexFrameWriter extends AbstractPackageIndexWriter {

    /**
     * Constructor.
     */
    public PackageIndexFrameWriter(String filename, 
                                   Root root) throws IOException {
        super(filename, root);
    }

    /**
     * Generate the package index.
     *
     * @param root the root of the doc tree.
     */
    public static void generate(Root root) throws DocletAbortException {
        PackageIndexFrameWriter packgen;
        String filename = "packages-frame.html";
        try {
            packgen = new PackageIndexFrameWriter(filename, root);
            packgen.generatePackageIndexFile();
            packgen.close();
        } catch (IOException exc) {
            error("doclet.exception_encountered", exc.toString(), filename);
            throw new DocletAbortException();
        }
    }

    protected void generateIndex() {
        printIndexContents(packages, ""); 
    }
 
    protected void printIndexRow(PackageDoc packagedoc) {
        String name = packagedoc.name();
        printTargetHyperLink("package-frame-" + name + ".html", 
                             "packageFrame", name);
        br();
    }

    protected void printNavigationBarHeader() {
        printHeadingInTable();
    }

    protected void printIndexHeader(String label) {
        printTableHeaderParams();
    }
   
    protected void printHeadingInTable() {
        if (configuration.header != null) {
            font("+1");
            print(configuration.header);
            fontEnd();
            printIndexFooter();
        }
    }
 
    protected void printNavigationBarFooter() {
        printTableFooterSpace();
    }

    protected void printIndexFooter() {
        tableEnd();
        trEnd();
        tdEnd();
    }

    protected void printTableHeaderParams() {
        tablePackageFrame();
        tr();
        td();
    }

    protected void printTableFooterSpace() {
        p();
        space();
    }

    protected void printOverview() throws IOException {
    }
}



