/*
 * @(#)PackageWriter.java	1.16 98/02/10
 *
 * Copyright 1993-1997 Sun Microsystems, Inc. 901 San Antonio Road,
 * Palo Alto, California, 94303, U.S.A.  All Rights Reserved.
 *
 * This software is the confidential and proprietary information of Sun
 * Microsystems, Inc. ("Confidential Information").  You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered into
 * with Sun.
 *
 * CopyrightVersion 1.2
 *
 */

package sun.tools.javadoc.doclets;

import sun.tools.javadoc.*;
import java.io.*;
import java.lang.*;
import java.util.*;
/**
 * Class to generate file for each package contents.
 *
 * @see sun.tools.javadoc.PackageDoc
 * @see sun.tools.javadoc.doclets.HtmlDocWriter
 * @author Atul M Dambalkar
 */
public class PackageWriter extends AbstractPackageWriter {

    /** 
     * The prev package name in the alpha-ordr list.
     */
    protected String prev;

    /** 
     * The next package name in the alpha-ordr list.
     */
    protected String next;

    /**
     * Constructor.
     */
    public PackageWriter(String filename, PackageDoc packagedoc,
                         String prev, String next) throws IOException {
        super(filename, packagedoc);
        this.prev = prev;
        this.next = next;
    }

    /**
     * Generate a package page.
     *
     * @param package the package to generate.
     */
    public static void generate(PackageDoc pkg, String prev,
                                String next) throws DocletAbortException {
        PackageWriter packgen;
        String filename = "package-" + pkg.toString() + ".html";
        try {
            packgen = new PackageWriter(filename, pkg, prev, next);
            packgen.generatePackageFile();
            packgen.close();
        } catch (IOException exc) {
            error("doclet.exception_encountered", exc.toString(), filename);
            throw new DocletAbortException();
        }
    }

    /**
     * Generate class listing for all classes in this package.
     */
    protected void generateClassListing() {
        generateClassKindListing(packagedoc.interfaces(), 
                                 getText("doclet.Interface_Summary"));
        generateClassKindListing(packagedoc.ordinaryClasses(),
                                 getText("doclet.Class_Summary"));
        generateClassKindListing(packagedoc.exceptions(),
                                 getText("doclet.Exception_Summary"));
        generateClassKindListing(packagedoc.errors(),
                                 getText("doclet.Error_Summary"));
    }
    
    /** 
     * This method is used by genIndPackageFiles method to generate
     * the Class/Interface... Listing.
     */
    protected void generateClassKindListing(ClassDoc[] arr, String label) {
        if(arr.length > 0) {
            Arrays.sort(arr, new ClassComparator());    
            tableIndexSummary();
            printFirstRow(label);
            for (int i = 0; i < arr.length; i++) {
                trBgcolor("#FFFFCC");
                summaryRow(15);
                bold();
                printClassLink(arr[i]);
                boldEnd();
                summaryRowEnd();
                summaryRow(0);
                String comment = firstSentence(arr[i].commentText());
                if (comment == "") {
                    comment = "&nbsp;";
                }
                println(comment);
                if (arr[i].tags("deprecated").length > 0) {
                    print(arr[i].tags("deprecated")[0].text()); 
                }
                summaryRowEnd();
                trEnd();
            }
            tableEnd();
            println("&nbsp;");
            p();
        }
    }

    /**
     * Print the table heading for the class-listing.
     */
    protected void printFirstRow(String label) {
        tableHeaderStart();
        bold(label);
        tableHeaderEnd();
    }

    /**
     * Print the package comment.
     */
    protected void printPackageComment() {
        String text = packagedoc.commentText();
        if (!text.equals("")) {
            h2(getText("doclet.Package_Description"));
            p();
            print(text); 
            p();
        }
    }
   
    /**
     * Print the package comment and the tag information.
     */ 
    protected void printPackageDescription() throws IOException {
        printPackageComment();
        generateTagInfo(packagedoc);
    }
    
    /**
     * Print the navigation bar links at the top.
     */                            
    protected void printPackageHeader(String heading) {
        navLinks(true);
        hr();
        h2(getText("doclet.Package") + " " + heading);
    }   

    /**
     * Print the navigation bar links at the bottom.
     */                            
    protected void printPackageFooter() {
        hr();
        navLinks(false);
        printBottom();
    }

    /**
     * Print previous package link
     */
    protected void navLinkPrevious() {
        if (prev == null) {
            navLinkPrevious(null);
        } else {
            navLinkPrevious("package-" + prev + ".html");
        }
    }
                                
    /**
     * Print next package link
     */
    protected void navLinkNext() {
        if (next == null) {
            navLinkNext(null);
        } else {
            navLinkNext("package-" + next + ".html");
        }
    }
}



